from ms_sdk.Entities.Entity import Entity


class Attribute(Entity):

    id = None
    code = None
    title = None
    showInSpecList = None
    useInFilter = None
    description = None
    attributeGroupId = None
    cssClass = None
    orderNumber = None

    values = None
    group = None

    attributeId = None
    productId = None